@@ -322,6 +322,22 @@ func (f *Client) AcquireLease(ctx context.Context, machineID string, ttl *int) (
 	return out, nil
 }
 
+func (f *Client) RefreshLease(ctx context.Context, machineID string, ttl *int, nonce string) (*api.MachineLease, error) {
+	endpoint := fmt.Sprintf("/%s/lease", machineID)
+	if ttl != nil {
+		endpoint += fmt.Sprintf("?ttl=%d", *ttl)
+	}
+	headers := make(map[string][]string)
+	headers[NonceHeader] = []string{nonce}
+	out := new(api.MachineLease)
+	err := f.sendRequest(ctx, http.MethodPost, endpoint, nil, out, headers)
+	if err != nil {
+		return nil, fmt.Errorf("failed to get lease on VM %s: %w", machineID, err)
+	}
+	terminal.Debugf("got lease on machine %s: %v\n", machineID, out)
+	return out, nil
+}
+
 func (f *Client) ReleaseLease(ctx context.Context, machineID, nonce string) error {
 	endpoint := fmt.Sprintf("/%s/lease", machineID)
 
