@@ -40,6 +40,7 @@ type Build struct {
 	Image string
 	// Or...
 	Dockerfile        string
+	Ignorefile        string
 	DockerBuildTarget string
 }
 
@@ -101,6 +102,13 @@ func (ac *AppConfig) Dockerfile() string {
 	return ac.Build.Dockerfile
 }
 
+func (ac *AppConfig) Ignorefile() string {
+	if ac.Build == nil {
+		return ""
+	}
+	return ac.Build.Ignorefile
+}
+
 func (ac *AppConfig) DockerBuildTarget() string {
 	if ac.Build == nil {
 		return ""
