@@ -233,7 +233,7 @@ func (md *machineDeployment) DeployMachinesApp(ctx context.Context) error {
 
 	fmt.Fprintf(md.io.Out, "Deploying %s app with %s strategy\n", md.colorize.Bold(md.app.Name), md.strategy)
 	for _, m := range md.machineSet.GetMachines() {
-		launchInput := md.resolveUpdatedMachineConfig(m.Machine())
+		launchInput := md.resolveUpdatedMachineConfig(m.Machine(), false)
 
 		fmt.Fprintf(md.io.ErrOut, "  Updating %s\n", md.colorize.Bold(m.FormattedMachineId()))
 		err := m.Update(ctx, *launchInput)
@@ -273,7 +273,7 @@ func (md *machineDeployment) DeployMachinesApp(ctx context.Context) error {
 
 func (md *machineDeployment) createOneMachine(ctx context.Context) error {
 	fmt.Fprintf(md.io.Out, "No machines in %s app, launching one new machine\n", md.colorize.Bold(md.app.Name))
-	launchInput := md.resolveUpdatedMachineConfig(nil)
+	launchInput := md.resolveUpdatedMachineConfig(nil, false)
 	newMachineRaw, err := md.flapsClient.Launch(ctx, *launchInput)
 	newMachine := machine.NewLeasableMachine(md.flapsClient, md.io, newMachineRaw)
 	if err != nil {
@@ -330,24 +330,15 @@ func (md *machineDeployment) setMachinesForDeployment(ctx context.Context) error
 
 func (md *machineDeployment) createOrUpdateReleaseCmdMachine(ctx context.Context) error {
 	if md.releaseCommandMachine.IsEmpty() {
-		err := md.createReleaseCommandMachine(ctx)
-		if err != nil {
-			return err
-		}
+		return md.createReleaseCommandMachine(ctx)
 	} else {
-		err := md.updateReleaseCommandMachine(ctx)
-		if err != nil {
-			return err
-		}
+		return md.updateReleaseCommandMachine(ctx)
 	}
-	return nil
 }
 
 func (md *machineDeployment) configureLaunchInputForReleaseCommand(launchInput *api.LaunchMachineInput) *api.LaunchMachineInput {
 	launchInput.Config.Init.Cmd = md.releaseCommand
 	launchInput.Config.Metadata[api.MachineConfigMetadataKeyFlyProcessGroup] = api.MachineProcessGroupFlyAppReleaseCommand
-	launchInput.Config.Services = nil
-	launchInput.Config.Checks = nil
 	launchInput.Config.Restart = api.MachineRestart{
 		Policy: api.MachineRestartPolicyNo,
 	}
@@ -366,8 +357,7 @@ func (md *machineDeployment) createReleaseCommandMachine(ctx context.Context) er
 	if len(md.releaseCommand) == 0 || !md.releaseCommandMachine.IsEmpty() {
 		return nil
 	}
-	launchInput := md.resolveUpdatedMachineConfig(nil)
-	launchInput = md.configureLaunchInputForReleaseCommand(launchInput)
+	launchInput := md.resolveUpdatedMachineConfig(nil, true)
 	releaseCmdMachine, err := md.flapsClient.Launch(ctx, *launchInput)
 	if err != nil {
 		return fmt.Errorf("error creating a release_command machine: %w", err)
@@ -390,8 +380,7 @@ func (md *machineDeployment) updateReleaseCommandMachine(ctx context.Context) er
 	if err != nil {
 		return err
 	}
-	updatedConfig := md.resolveUpdatedMachineConfig(releaseCmdMachine.Machine())
-	updatedConfig = md.configureLaunchInputForReleaseCommand(updatedConfig)
+	updatedConfig := md.resolveUpdatedMachineConfig(releaseCmdMachine.Machine(), true)
 	err = md.releaseCommandMachine.AcquireLeases(ctx, md.leaseTimeout)
 	defer func() {
 		_ = md.releaseCommandMachine.ReleaseLeases(ctx)
@@ -532,55 +521,65 @@ func (md *machineDeployment) createReleaseInBackend(ctx context.Context) error {
 	return nil
 }
 
-func (md *machineDeployment) resolveUpdatedMachineConfig(origMachineRaw *api.Machine) *api.LaunchMachineInput {
+func (md *machineDeployment) resolveUpdatedMachineConfig(origMachineRaw *api.Machine, forReleaseCommand bool) *api.LaunchMachineInput {
 	if origMachineRaw == nil {
 		origMachineRaw = &api.Machine{
 			Region: md.appConfig.PrimaryRegion,
 			Config: &api.MachineConfig{},
 		}
 	}
-	machineConf := &api.MachineConfig{}
-	if md.restartOnly {
-		machineConf = origMachineRaw.Config
-	}
+
 	launchInput := &api.LaunchMachineInput{
 		ID:      origMachineRaw.ID,
 		AppID:   md.app.Name,
 		OrgSlug: md.app.Organization.ID,
-		Config:  machineConf,
+		Config:  lo.Ternary(md.restartOnly, origMachineRaw.Config, &api.MachineConfig{}),
 		Region:  origMachineRaw.Region,
 	}
+
 	launchInput.Config.Metadata = md.defaultMachineMetadata()
-	if origMachineRaw.Config.Metadata != nil {
-		for k, v := range origMachineRaw.Config.Metadata {
-			if !isFlyAppsPlatformMetadata(k) {
-				launchInput.Config.Metadata[k] = v
-			}
+	for k, v := range origMachineRaw.Config.Metadata {
+		if !isFlyAppsPlatformMetadata(k) {
+			launchInput.Config.Metadata[k] = v
 		}
 	}
+
+	// Stop here If the machine is restarting
 	if md.restartOnly {
 		return launchInput
 	}
 
 	launchInput.Config.Image = md.img.Tag
-	launchInput.Config.Metrics = md.appConfig.Metrics
 	launchInput.Config.Restart = origMachineRaw.Config.Restart
+	launchInput.Config.Guest = origMachineRaw.Config.Guest
+	launchInput.Config.Init = origMachineRaw.Config.Init
+	launchInput.Config.Env = lo.Assign(md.appConfig.Env)
+
+	if launchInput.Config.Env["PRIMARY_REGION"] == "" && origMachineRaw.Config.Env["PRIMARY_REGION"] != "" {
+		launchInput.Config.Env["PRIMARY_REGION"] = origMachineRaw.Config.Env["PRIMARY_REGION"]
+	}
+
+	// Stop here If the machine is for release command
+	if forReleaseCommand {
+		return md.configureLaunchInputForReleaseCommand(launchInput)
+	}
+
+	// Anything below this point doesn't apply to machines created to run ReleaseCommand
+	launchInput.Config.Metrics = md.appConfig.Metrics
+
 	for _, s := range md.appConfig.Statics {
 		launchInput.Config.Statics = append(launchInput.Config.Statics, &api.Static{
 			GuestPath: s.GuestPath,
 			UrlPrefix: s.UrlPrefix,
 		})
 	}
-	launchInput.Config.Env = make(map[string]string)
-	for k, v := range md.appConfig.Env {
-		launchInput.Config.Env[k] = v
-	}
-	if launchInput.Config.Env["PRIMARY_REGION"] == "" && origMachineRaw.Config.Env["PRIMARY_REGION"] != "" {
-		launchInput.Config.Env["PRIMARY_REGION"] = origMachineRaw.Config.Env["PRIMARY_REGION"]
-	}
 
-	if origMachineRaw.Config.Mounts != nil {
-		launchInput.Config.Mounts = origMachineRaw.Config.Mounts
+	launchInput.Config.Mounts = origMachineRaw.Config.Mounts
+	if launchInput.Config.Mounts == nil && md.appConfig.Mounts != nil {
+		launchInput.Config.Mounts = []api.MachineMount{{
+			Path:   md.volumeDestination,
+			Volume: md.volumes[0].ID,
+		}}
 	}
 
 	if len(launchInput.Config.Mounts) == 1 && launchInput.Config.Mounts[0].Path != md.volumeDestination {
@@ -588,19 +587,17 @@ func (md *machineDeployment) resolveUpdatedMachineConfig(origMachineRaw *api.Mac
 		terminal.Warnf("Updating the mount path for volume %s on machine %s from %s to %s due to fly.toml [mounts] destination value\n", currentMount.Volume, origMachineRaw.ID, currentMount.Path, md.volumeDestination)
 		launchInput.Config.Mounts[0].Path = md.volumeDestination
 	}
-	if origMachineRaw.Config.Guest != nil {
-		launchInput.Config.Guest = origMachineRaw.Config.Guest
-	}
-	launchInput.Config.Init = origMachineRaw.Config.Init
-	processGroup := origMachineRaw.Config.Metadata[api.MachineConfigMetadataKeyFlyProcessGroup]
+
+	processGroup := launchInput.Config.Metadata[api.MachineConfigMetadataKeyFlyProcessGroup]
 	if processGroup == "" {
 		processGroup = api.MachineProcessGroupApp
 	}
 	if processConfig, ok := md.processConfigs[processGroup]; ok {
 		launchInput.Config.Services = processConfig.Services
-		launchInput.Config.Init.Cmd = processConfig.Cmd
 		launchInput.Config.Checks = processConfig.Checks
+		launchInput.Config.Init.Cmd = lo.Ternary(len(processConfig.Cmd) > 0, processConfig.Cmd, nil)
 	}
+
 	return launchInput
 }
 
