@@ -20,8 +20,7 @@ func newUnset() (cmd *cobra.Command) {
 	cmd = command.New(usage, short, long, runUnset, command.RequireSession, command.LoadAppNameIfPresent)
 
 	flag.Add(cmd,
-		flag.App(),
-		flag.AppConfig(),
+		sharedFlags,
 	)
 
 	cmd.Args = cobra.MinimumNArgs(1)
@@ -33,13 +32,11 @@ func runUnset(ctx context.Context) (err error) {
 	client := client.FromContext(ctx).API()
 	appName := app.NameFromContext(ctx)
 	app, err := client.GetAppCompact(ctx, appName)
-
 	if err != nil {
 		return err
 	}
 
 	release, err := client.UnsetSecrets(ctx, appName, flag.Args(ctx))
-
 	if err != nil {
 		return err
 	}
